<?php
/**
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace OCA\SideMenu\Settings;

use OCA\SideMenu\AppInfo\Application;
use OCA\SideMenu\Service\AppRepository;
use OCA\SideMenu\Service\CategoryRepository;
use OCA\SideMenu\Service\ConfigProxy;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\IL10N;
use OCP\ILogger;
use OCP\Settings\ISettings;

class Admin implements ISettings
{
    /**
     * @var IL10N
     */
    private $l;

    /**
     * @var ILogger
     */
    private $logger;

    /**
     * @var ConfigProxy
     */
    private $config;

    /**
     * @var AppRepository
     */
    private $appRepository;

    /**
     * @var CategoryRepository
     */
    private $categoryRepository;

    public function __construct(
        IL10N $l,
        ILogger $logger,
        ConfigProxy $config,
        AppRepository $appRepository,
        CategoryRepository $categoryRepository
    ) {
        $this->l = $l;
        $this->logger = $logger;
        $this->config = $config;
        $this->appRepository = $appRepository;
        $this->categoryRepository = $categoryRepository;
    }

    /**
     * @return TemplateResponse
     */
    public function getForm()
    {
        $backgroundColor = $this->config->getAppValue('background-color', '#333333');
        $backgroundColorTo = $this->config->getAppValue('background-color-to', $backgroundColor);

        $parameters = [
            'background-color' => $backgroundColor,
            'background-color-to' => $backgroundColorTo,
            'current-app-background-color' => $this->config->getAppValue('current-app-background-color', '#444444'),
            'loader-color' => $this->config->getAppValue('loader-color', '#0e75ac'),
            'icon-invert-filter' => $this->config->getAppValueInt('icon-invert-filter', '0'),
            'icon-opacity' => $this->config->getAppValueInt('icon-opacity', '100'),
            'loader-enabled' => $this->config->getAppValue('loader-enabled', '1'),
            'text-color' => $this->config->getAppValue('text-color', '#FFFFFF'),
            'cache' => $this->config->getAppValue('cache', '0'),
            'opener' => $this->config->getAppValue('opener', 'side-menu-opener'),
            'always-displayed' => $this->config->getAppValue('always-displayed', '0'),
            'big-menu' => $this->config->getAppValue('big-menu', '0'),
            'big-menu-hidden-apps' => $this->config->getAppValueArray('big-menu-hidden-apps', '[]'),
            'display-logo' => $this->config->getAppValue('display-logo', '1'),
            'add-logo-link' => $this->config->getAppValue('add-logo-link', '1'),
            'use-avatar' => $this->config->getAppValue('use-avatar', '0'),
            'opener-position' => $this->config->getAppValue('opener-position', 'before'),
            'opener-hover' => $this->config->getAppValue('opener-hover', '0'),
            'opener-only' => $this->config->getAppValue('opener-only', '0'),
            'show-settings' => $this->config->getAppValue('show-settings', '0'),
            'hide-when-no-apps' => $this->config->getAppValue('hide-when-no-apps', '0'),
            'size-icon' => $this->config->getAppValue('size-icon', 'normal'),
            'size-text' => $this->config->getAppValue('size-text', 'normal'),
            'force' => $this->config->getAppValue('force', '0'),
            'target-blank-apps' => $this->config->getAppValueArray('target-blank-apps', '[]'),
            'top-menu-apps' => $this->config->getAppValueArray('top-menu-apps', '[]'),
            'default-enabled' => $this->config->getAppValue('default-enabled', '1'),
            'categories-order-type' => $this->config->getAppValue('categories-order-type', 'default'),
            'categories-order' => $this->config->getAppValueArray('categories-order', '[]'),
            'apps' => $this->appRepository->getVisibleApps(),
            'categories' => $this->categoryRepository->getOrderedCategories(),
        ];

        return new TemplateResponse(Application::APP_ID, 'settings/admin-form', $parameters, '');
    }

    /**
     * @return string the section ID, e.g. 'sharing'
     */
    public function getSection()
    {
        return Application::APP_ID;
    }

    /**
     * @return int whether the form should be rather on the top or bottom of
     *             the admin section. The forms are arranged in ascending order of the
     *             priority values. It is required to return a value between 0 and 100.
     *
     * E.g.: 70
     */
    public function getPriority()
    {
        return 70;
    }
}
